@@ -27,7 +27,7 @@
 #' data(lakes)
 #' lakeFetch(inputLM,45)
 
-lakeFetch <- function(inLakeMorpho, bearing, addLine = T) {
+lakeFetch <- function(inLakeMorpho, bearing, addLine = TRUE) {
     inputName <- deparse(substitute(inLakeMorpho))
     if (class(inLakeMorpho) != "lakeMorpho") {
       stop("Input data is not of class 'lakeMorpho'.  Run lakeSurround Topo or lakeMorphoClass first.")
@@ -98,7 +98,7 @@ lakeFetch <- function(inLakeMorpho, bearing, addLine = T) {
     # clip out lines that are inside lake
     lakeLinesSL <- gIntersection(lakedd, allLinesSL, byid = TRUE)
     
-    myInd <- gWithin(lakeLinesSL, lakedd, byid = T)
+    myInd <- gWithin(lakeLinesSL, lakedd, byid = TRUE)
     lakeLinesSL_proj <- spTransform(lakeLinesSL, CRSobj = CRS(proj4string(inLakeMorpho$lake)))
     # Loop through each item in lakeLinesSL_Proj and create a SpatialLines object for each segment.
     lakeLinesList_proj <- list()
@@ -113,11 +113,11 @@ lakeFetch <- function(inLakeMorpho, bearing, addLine = T) {
     
     # Determine the longest
     lakeLinesSL_proj <- SpatialLines(lakeLinesList_proj, proj4string = CRS(proj4string(inLakeMorpho$lake)))
-    result <- max(gLength(lakeLinesSL_proj, byid = TRUE), na.rm = T)
+    result <- max(gLength(lakeLinesSL_proj, byid = TRUE), na.rm = TRUE)
     if(capabilities("long.double")){
-      myLine <- lakeLinesSL_proj[gLength(lakeLinesSL_proj, byid = T) == result, ]
+      myLine <- lakeLinesSL_proj[gLength(lakeLinesSL_proj, byid = TRUE) == result, ]
     } else {
-      myLine <- lakeLinesSL_proj[round(gLength(lakeLinesSL_proj, byid = T),8) == round(result,8), ]
+      myLine <- lakeLinesSL_proj[round(gLength(lakeLinesSL_proj, byid = TRUE),8) == round(result,8), ]
     }
     
     # line added to input lakemorpho
@@ -128,5 +128,5 @@ lakeFetch <- function(inLakeMorpho, bearing, addLine = T) {
         class(inLakeMorpho) <- "lakeMorpho"
         assign(inputName, inLakeMorpho, envir = parent.frame())
     }
-    return(result)
+    return(round(result,4))
 } 
