@@ -61,5 +61,5 @@ lakeMajorAxisLength <- function(inLakeMorpho, addLine = TRUE) {
     class(inLakeMorpho) <- "lakeMorpho"
     assign(myName, inLakeMorpho, envir = parent.frame())
   }
-  return(result)
+  return(round(result,4))
 } 
